# API Reference

This section contains the complete API reference for the `baygon` package.
It is generated automatically from the source code using `mkdocstrings`
and reflects the latest docstrings available in the project.

::: baygon
    options:
      show_root_heading: true
      show_root_full_path: false
      members_order: source
      separate_signature: true
      show_category_heading: true
      show_submodules: true
